# goonies
> down here, it's our time. it's our time down here.

- [license](#license)

# license

Copyright © 2024 tolitius

Distributed under the Eclipse Public License either version 1.0 or (at
your option) any later version.
